@@ -62,13 +62,13 @@ public:
     virtual QString imageCodecDescription(const QString &codecName) const = 0;
 
     virtual QList<QSize> supportedResolutions(const QImageEncoderSettings &settings,
-                                              bool *continuous = 0) const = 0;
+                                              bool *continuous = Q_NULLPTR) const = 0;
 
     virtual QImageEncoderSettings imageSettings() const = 0;
     virtual void setImageSettings(const QImageEncoderSettings &settings) = 0;
 
 protected:
-    QImageEncoderControl(QObject *parent = 0);
+    explicit QImageEncoderControl(QObject *parent = Q_NULLPTR);
 };
 
 #define QImageEncoderControl_iid "org.qt-project.qt.imageencodercontrol/5.0"
