@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd and/or its subsidiary(-ies).
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -44,10 +36,15 @@
 #include "coreaudioutils.h"
 
 #if defined(Q_OS_OSX)
-# include <CoreServices/CoreServices.h>
+# include <AudioUnit/AudioComponent.h>
+#endif
+
+#if defined(Q_OS_IOS)
+# include "coreaudiosessionmanager.h"
 #endif
 
 #include <QtMultimedia/private/qaudiohelpers_p.h>
+#include <QtCore/QDataStream>
 #include <QtCore/QDebug>
 
 QT_BEGIN_NAMESPACE
@@ -483,31 +480,15 @@ bool CoreAudioInput::open()
     if (m_isOpen)
         return true;
 
-#if defined(Q_OS_OSX)
     UInt32  size = 0;
 
-    ComponentDescription componentDescription;
-    componentDescription.componentType = kAudioUnitType_Output;
-    componentDescription.componentSubType = kAudioUnitSubType_HALOutput;
-    componentDescription.componentManufacturer = kAudioUnitManufacturer_Apple;
-    componentDescription.componentFlags = 0;
-    componentDescription.componentFlagsMask = 0;
-
-    // Open
-    Component component = FindNextComponent(NULL, &componentDescription);
-    if (component == 0) {
-        qWarning() << "QAudioInput: Failed to find HAL Output component";
-        return false;
-    }
-
-    if (OpenAComponent(component, &m_audioUnit) != noErr) {
-        qWarning() << "QAudioInput: Unable to Open Output Component";
-        return false;
-    }
-#else //iOS
     AudioComponentDescription componentDescription;
     componentDescription.componentType = kAudioUnitType_Output;
+#if defined(Q_OS_OSX)
+    componentDescription.componentSubType = kAudioUnitSubType_HALOutput;
+#else
     componentDescription.componentSubType = kAudioUnitSubType_RemoteIO;
+#endif
     componentDescription.componentManufacturer = kAudioUnitManufacturer_Apple;
     componentDescription.componentFlags = 0;
     componentDescription.componentFlagsMask = 0;
@@ -522,7 +503,7 @@ bool CoreAudioInput::open()
         qWarning() << "QAudioInput: Unable to Open Output Component";
         return false;
     }
-#endif
+
     // Set mode
     // switch to input mode
     UInt32 enable = 1;
@@ -690,12 +671,7 @@ void CoreAudioInput::close()
     if (m_audioUnit != 0) {
         AudioOutputUnitStop(m_audioUnit);
         AudioUnitUninitialize(m_audioUnit);
-#if defined(Q_OS_OSX)
-        CloseComponent(m_audioUnit);
-#else //iOS
         AudioComponentInstanceDispose(m_audioUnit);
-#endif
-
     }
 
     delete m_audioBuffer;
